#
# spec file for package python-geomet
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-geomet
Version:        1.0.0
Release:        1.3
Summary:        GeoJSON <-> WKT/WKB conversion utilities
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/geomet/geomet
Source:         https://github.com/geomet/geomet/archive/%{version}.tar.gz
# https://github.com/geomet/geomet/issues/90
Patch0:         python-geomet-no-six.patch
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-click
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
GeoJSON <-> WKT/WKB conversion utilities

%prep
%autosetup -p1 -n geomet-%{version}

%build
sed -i '1{/^#!/ d}' geomet/*.py
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/geomet
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%post
%python_install_alternative geomet

%postun
%python_uninstall_alternative geomet

%files %{python_files}
%doc AUTHORS.txt README.md
%license LICENSE
%python_alternative %{_bindir}/geomet
%{python_sitelib}/geomet
%{python_sitelib}/geomet-%{version}-py*.egg-info

%changelog
* Thu May 11 2023 pgajdos@suse.com
- version update to 1.0.0
  * Fix bug in _round_and_pad with exponential coordinate values (#73)
  * Use assertNotEqual instead of assertNotEquals in tests, for Python 3.11 compatibility (#77)
  * Add support for Python 3.8, 3.9, and 3.10 (#79, #84)
  * Drop support for end-of-life Python versions 2.7, 3.4, 3.5, and 3.6 (#84)
  * Fix structure of coordinate values in GeoJSON to EsriJSON conversion (#82)
  * Update README with to add History and Limitations sections, and to expand on functionality (#86)
- added patches
  fix https://github.com/geomet/geomet/issues/90
  + python-geomet-no-six.patch
* Wed Nov  4 2020 Johannes Grassler <johannes.grassler@suse.com>
- Fix executable name substitution for Python 3 tests
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jan 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Switch to github archive in order to get tests
* Sat Jan 18 2020 Arun Persaud <arun@gmx.de>
- initial package (needed for cassandra driver)
